==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/plugins/formmanagerplugin/formmanagermode.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2012 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main developers : Eric MAEKER, <eric.maeker@gmail.com>                *
 *   Contributors :                                                        *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef FORMMANAGERMODE_H
#define FORMMANAGERMODE_H

#include <coreplugin/modemanager/basemode.h>

#include <QObject>

/**
 * \file formmanagermode.h
 * \author Eric MAEKER <eric.maeker@gmail.com>
 * \version 0.5.0
 * \date 25 Mar 2011
*/


namespace Form {
class FormPlaceHolder;
namespace Internal {

class FormManagerMode : public Core::BaseMode
{
    Q_OBJECT
public:
    FormManagerMode(QObject *parent);
    ~FormManagerMode();

    QString name() const;

private Q_SLOTS:
    bool getPatientForm();

private:
//    bool eventFilter(QObject *obj, QEvent *event);

private:
    FormPlaceHolder *m_Holder;
    bool m_inPluginManager, m_actionInBar;
};

}  // End namespace Internal
}  // End namespace Form

#endif // FORMMANAGERMODE_H

==> freemedforms-project_0.9.0.orig.tar.gz: freemedforms-0.9.0/plugins/formmanagerplugin/formmanagermode.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *  Main developer: Eric MAEKER, <eric.maeker@gmail.com>                   *
 *  Contributors:                                                          *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef FORMMANAGERMODE_H
#define FORMMANAGERMODE_H

#include <coreplugin/modemanager/imode.h>

#include <QObject>

/**
 * \file formmanagermode.h
 * \author Eric MAEKER <eric.maeker@gmail.com>
 * \version 0.5.0
 * \date 25 Mar 2011
*/


namespace Form {
class FormPlaceHolder;
namespace Internal {

class FormManagerMode : public Core::IMode
{
    Q_OBJECT
public:
    FormManagerMode(QObject *parent);
    ~FormManagerMode();

    QString name() const;

private Q_SLOTS:
    bool onPatientFormsLoaded();

private:
//    bool eventFilter(QObject *obj, QEvent *event);

private:
    FormPlaceHolder *m_Holder;
    bool m_inPluginManager, m_actionInBar;
};

}  // End namespace Internal
}  // End namespace Form

#endif // FORMMANAGERMODE_H
